==> gaga_1.10.0.zip: gaga/doc/gagamanual.R <==
###################################################
### chunk number 1: one
###################################################
#line 148 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
library(gaga)
set.seed(10)
n <- 100; m <- c(6,6)
a0 <- 25.5; nu <- 0.109
balpha <- 1.183; nualpha <- 1683
probpat <- c(.95,.05)
xsim <- simGG(n,m,p.de=probpat[2],a0,nu,balpha,nualpha,equalcv=TRUE)


###################################################
### chunk number 2: two
###################################################
#line 170 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
xsim
featureData(xsim)
phenoData(xsim)
a <- fData(xsim)[,c("alpha.1","alpha.2")]
l <- fData(xsim)[,c("mean.1","mean.2")]
x <- exprs(xsim)


###################################################
### chunk number 3: fig1aplot
###################################################
#line 187 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
plot(density(x),xlab='Expression levels',main='')


###################################################
### chunk number 4: fig1bplot
###################################################
#line 191 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
plot(l[,1],1/sqrt(a[,1]),xlab='Group 1 Mean',ylab='Group 1 CV')


###################################################
### chunk number 5: fig1a
###################################################
#line 200 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
#line 187 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw#from line#200#"
plot(density(x),xlab='Expression levels',main='')
#line 201 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"


###################################################
### chunk number 6: fig1b
###################################################
#line 203 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
#line 191 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw#from line#203#"
plot(l[,1],1/sqrt(a[,1]),xlab='Group 1 Mean',ylab='Group 1 CV')
#line 204 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"


###################################################
### chunk number 7: three
###################################################
#line 242 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
groups <- pData(xsim)$group[c(-6,-12)]
groups
patterns <- matrix(c(0,0,0,1),2,2)
colnames(patterns) <- c('group 1','group 2')
patterns


###################################################
### chunk number 8: threebis
###################################################
#line 260 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
patterns <- matrix(c(0,0,0,0,1,1,0,0,1,0,1,2),ncol=3,byrow=TRUE)
colnames(patterns) <- c('CONTROL','CANCER A','CANCER B')
patterns


###################################################
### chunk number 9: four
###################################################
#line 301 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
patterns <- matrix(c(0,0,0,1),2,2)
colnames(patterns) <- c('group 1','group 2')
gg1 <- fitGG(x[,c(-6,-12)],groups,patterns=patterns,nclust=1,method='Gibbs',B=1000,trace=FALSE)
gg2 <- fitGG(x[,c(-6,-12)],groups,patterns=patterns,method='EM',trace=FALSE)  
gg3 <- fitGG(x[,c(-6,-12)],groups,patterns=patterns,method='quickEM',trace=FALSE)  


###################################################
### chunk number 10: five
###################################################
#line 323 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
gg1 <- parest(gg1,x=x[,c(-6,-12)],groups,burnin=100,alpha=.05)
gg2 <- parest(gg2,x=x[,c(-6,-12)],groups,alpha=.05)
gg3 <- parest(gg3,x=x[,c(-6,-12)],groups,alpha=.05)
gg1
gg1$ci
gg2
gg3


###################################################
### chunk number 11: seven
###################################################
#line 348 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
dim(gg1$pp)
gg1$pp[1,]
gg2$pp[1,]


###################################################
### chunk number 12: fig4aplot
###################################################
#line 372 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
checkfit(gg1,x=x[,c(-6,-12)],groups,type='data',main='')


###################################################
### chunk number 13: fig4bplot
###################################################
#line 376 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
checkfit(gg1,x=x[,c(-6,-12)],groups,type='shape',main='')


###################################################
### chunk number 14: fig4cplot
###################################################
#line 381 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
checkfit(gg1,x=x[,c(-6,-12)],groups,type='mean',main='')


###################################################
### chunk number 15: fig4dplot
###################################################
#line 386 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
checkfit(gg1,x=x[,c(-6,-12)],groups,type='shapemean',main='',xlab='Mean',ylab='1/sqrt(CV)')


###################################################
### chunk number 16: fig4a
###################################################
#line 396 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
#line 372 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw#from line#396#"
checkfit(gg1,x=x[,c(-6,-12)],groups,type='data',main='')
#line 397 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"


###################################################
### chunk number 17: fig4b
###################################################
#line 399 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
#line 376 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw#from line#399#"
checkfit(gg1,x=x[,c(-6,-12)],groups,type='shape',main='')
#line 400 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"


###################################################
### chunk number 18: fig4c
###################################################
#line 403 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
#line 381 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw#from line#403#"
checkfit(gg1,x=x[,c(-6,-12)],groups,type='mean',main='')
#line 404 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"


###################################################
### chunk number 19: fig4d
###################################################
#line 406 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
#line 386 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw#from line#406#"
checkfit(gg1,x=x[,c(-6,-12)],groups,type='shapemean',main='',xlab='Mean',ylab='1/sqrt(CV)')
#line 407 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"


###################################################
### chunk number 20: eight
###################################################
#line 443 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
d1 <- findgenes(gg1,x[,c(-6,-12)],groups,fdrmax=.05,parametric=TRUE)
d1.nonpar <- findgenes(gg1,x[,c(-6,-12)],groups,fdrmax=.05,parametric=FALSE,B=1000)
dtrue <- (l[,1]!=l[,2])
table(d1$d,dtrue)
table(d1.nonpar$d,dtrue)


###################################################
### chunk number 21: fig5plot
###################################################
#line 466 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
plot(d1.nonpar$fdrest,type='l',xlab='Bayesian FDR',ylab='Estimated frequentist FDR')


###################################################
### chunk number 22: fig1
###################################################
#line 472 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
#line 466 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw#from line#472#"
plot(d1.nonpar$fdrest,type='l',xlab='Bayesian FDR',ylab='Estimated frequentist FDR')
#line 473 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"


###################################################
### chunk number 23: eightbis
###################################################
#line 484 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
d2 <- findgenes(gg2,x[,c(-6,-12)],groups,fdrmax=.05,parametric=TRUE)
d3 <- findgenes(gg3,x[,c(-6,-12)],groups,fdrmax=.05,parametric=TRUE)
table(d1$d,d2$d)
table(d1$d,d3$d)


###################################################
### chunk number 24: fc1
###################################################
#line 522 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
mpos <- posmeansGG(gg1,x=x[,c(-6,-12)],groups=groups,underpattern=1)
fc <- mpos[,1]-mpos[,2]
fc[1:5]


###################################################
### chunk number 25: nine
###################################################
#line 562 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprT9pUJ/R.INSTALL138e5b6e/gaga/inst/doc/gagamanual.Rnw"
pred1 <- classpred(gg1,xnew=x[,6],x=x[,c(-6,-12)],groups,ngene=50,prgroups=c(.5,.5))
pred2 <- classpred(gg1,xnew=x[,12],x=x[,c(-6,-12)],groups,ngene=50,prgroups=c(.5,.5))
pred1
pred2

==> gaga_1.12.0.zip: gaga/doc/gagamanual.R <==
###################################################
### chunk number 1: one
###################################################
#line 148 "gagamanual.Rnw"
library(gaga)
set.seed(10)
n <- 100; m <- c(6,6)
a0 <- 25.5; nu <- 0.109
balpha <- 1.183; nualpha <- 1683
probpat <- c(.95,.05)
xsim <- simGG(n,m,p.de=probpat[2],a0,nu,balpha,nualpha,equalcv=TRUE)


###################################################
### chunk number 2: two
###################################################
#line 170 "gagamanual.Rnw"
xsim
featureData(xsim)
phenoData(xsim)
a <- fData(xsim)[,c("alpha.1","alpha.2")]
l <- fData(xsim)[,c("mean.1","mean.2")]
x <- exprs(xsim)


###################################################
### chunk number 3: fig1aplot
###################################################
#line 187 "gagamanual.Rnw"
plot(density(x),xlab='Expression levels',main='')


###################################################
### chunk number 4: fig1bplot
###################################################
#line 191 "gagamanual.Rnw"
plot(l[,1],1/sqrt(a[,1]),xlab='Group 1 Mean',ylab='Group 1 CV')


###################################################
### chunk number 5: fig1a
###################################################
#line 200 "gagamanual.Rnw"
#line 187 "gagamanual.Rnw"
plot(density(x),xlab='Expression levels',main='')
#line 201 "gagamanual.Rnw"


###################################################
### chunk number 6: fig1b
###################################################
#line 203 "gagamanual.Rnw"
#line 191 "gagamanual.Rnw"
plot(l[,1],1/sqrt(a[,1]),xlab='Group 1 Mean',ylab='Group 1 CV')
#line 204 "gagamanual.Rnw"


###################################################
### chunk number 7: three
###################################################
#line 242 "gagamanual.Rnw"
groups <- pData(xsim)$group[c(-6,-12)]
groups
patterns <- matrix(c(0,0,0,1),2,2)
colnames(patterns) <- c('group 1','group 2')
patterns


###################################################
### chunk number 8: threebis
###################################################
#line 260 "gagamanual.Rnw"
patterns <- matrix(c(0,0,0,0,1,1,0,0,1,0,1,2),ncol=3,byrow=TRUE)
colnames(patterns) <- c('CONTROL','CANCER A','CANCER B')
patterns


###################################################
### chunk number 9: four
###################################################
#line 301 "gagamanual.Rnw"
patterns <- matrix(c(0,0,0,1),2,2)
colnames(patterns) <- c('group 1','group 2')
gg1 <- fitGG(x[,c(-6,-12)],groups,patterns=patterns,nclust=1,method='Gibbs',B=1000,trace=FALSE)
gg2 <- fitGG(x[,c(-6,-12)],groups,patterns=patterns,method='EM',trace=FALSE)  
gg3 <- fitGG(x[,c(-6,-12)],groups,patterns=patterns,method='quickEM',trace=FALSE)  


###################################################
### chunk number 10: five
###################################################
#line 323 "gagamanual.Rnw"
gg1 <- parest(gg1,x=x[,c(-6,-12)],groups,burnin=100,alpha=.05)
gg2 <- parest(gg2,x=x[,c(-6,-12)],groups,alpha=.05)
gg3 <- parest(gg3,x=x[,c(-6,-12)],groups,alpha=.05)
gg1
gg1$ci
gg2
gg3


###################################################
### chunk number 11: seven
###################################################
#line 348 "gagamanual.Rnw"
dim(gg1$pp)
gg1$pp[1,]
gg2$pp[1,]


###################################################
### chunk number 12: fig4aplot
###################################################
#line 372 "gagamanual.Rnw"
checkfit(gg1,x=x[,c(-6,-12)],groups,type='data',main='')


###################################################
### chunk number 13: fig4bplot
###################################################
#line 376 "gagamanual.Rnw"
checkfit(gg1,x=x[,c(-6,-12)],groups,type='shape',main='')


###################################################
### chunk number 14: fig4cplot
###################################################
#line 381 "gagamanual.Rnw"
checkfit(gg1,x=x[,c(-6,-12)],groups,type='mean',main='')


###################################################
### chunk number 15: fig4dplot
###################################################
#line 386 "gagamanual.Rnw"
checkfit(gg1,x=x[,c(-6,-12)],groups,type='shapemean',main='',xlab='Mean',ylab='1/sqrt(CV)')


###################################################
### chunk number 16: fig4a
###################################################
#line 396 "gagamanual.Rnw"
#line 372 "gagamanual.Rnw"
checkfit(gg1,x=x[,c(-6,-12)],groups,type='data',main='')
#line 397 "gagamanual.Rnw"


###################################################
### chunk number 17: fig4b
###################################################
#line 399 "gagamanual.Rnw"
#line 376 "gagamanual.Rnw"
checkfit(gg1,x=x[,c(-6,-12)],groups,type='shape',main='')
#line 400 "gagamanual.Rnw"


###################################################
### chunk number 18: fig4c
###################################################
#line 403 "gagamanual.Rnw"
#line 381 "gagamanual.Rnw"
checkfit(gg1,x=x[,c(-6,-12)],groups,type='mean',main='')
#line 404 "gagamanual.Rnw"


###################################################
### chunk number 19: fig4d
###################################################
#line 406 "gagamanual.Rnw"
#line 386 "gagamanual.Rnw"
checkfit(gg1,x=x[,c(-6,-12)],groups,type='shapemean',main='',xlab='Mean',ylab='1/sqrt(CV)')
#line 407 "gagamanual.Rnw"


###################################################
### chunk number 20: eight
###################################################
#line 443 "gagamanual.Rnw"
d1 <- findgenes(gg1,x[,c(-6,-12)],groups,fdrmax=.05,parametric=TRUE)
d1.nonpar <- findgenes(gg1,x[,c(-6,-12)],groups,fdrmax=.05,parametric=FALSE,B=1000)
dtrue <- (l[,1]!=l[,2])
table(d1$d,dtrue)
table(d1.nonpar$d,dtrue)


###################################################
### chunk number 21: fig5plot
###################################################
#line 466 "gagamanual.Rnw"
plot(d1.nonpar$fdrest,type='l',xlab='Bayesian FDR',ylab='Estimated frequentist FDR')


###################################################
### chunk number 22: fig1
###################################################
#line 472 "gagamanual.Rnw"
#line 466 "gagamanual.Rnw"
plot(d1.nonpar$fdrest,type='l',xlab='Bayesian FDR',ylab='Estimated frequentist FDR')
#line 473 "gagamanual.Rnw"


###################################################
### chunk number 23: eightbis
###################################################
#line 484 "gagamanual.Rnw"
d2 <- findgenes(gg2,x[,c(-6,-12)],groups,fdrmax=.05,parametric=TRUE)
d3 <- findgenes(gg3,x[,c(-6,-12)],groups,fdrmax=.05,parametric=TRUE)
table(d1$d,d2$d)
table(d1$d,d3$d)


###################################################
### chunk number 24: fc1
###################################################
#line 522 "gagamanual.Rnw"
mpos <- posmeansGG(gg1,x=x[,c(-6,-12)],groups=groups,underpattern=1)
fc <- mpos[,1]-mpos[,2]
fc[1:5]


###################################################
### chunk number 25: nine
###################################################
#line 562 "gagamanual.Rnw"
pred1 <- classpred(gg1,xnew=x[,6],x=x[,c(-6,-12)],groups,ngene=50,prgroups=c(.5,.5))
pred2 <- classpred(gg1,xnew=x[,12],x=x[,c(-6,-12)],groups,ngene=50,prgroups=c(.5,.5))
pred1
pred2
